pub struct LightEngine { /* private fields */ }Implementations
Sourceimpl LightEngine
impl LightEngine
pub fn new() -> Self
pub fn place_light( &mut self, access: &impl VoxelAccess, pos: [i32; 3], level: u8, ) -> Vec<LightUpdate>
pub fn remove_light( &mut self, access: &impl VoxelAccess, pos: [i32; 3], ) -> Vec<LightUpdate>
pub fn block_placed( &mut self, access: &impl VoxelAccess, pos: [i32; 3], ) -> Vec<LightUpdate>
pub fn block_removed( &mut self, access: &impl VoxelAccess, pos: [i32; 3], ) -> Vec<LightUpdate>
Sourcepub fn recalculate_area(
&mut self,
access: &impl VoxelAccess,
center: [i32; 3],
radius: i32,
) -> Vec<LightUpdate>
pub fn recalculate_area( &mut self, access: &impl VoxelAccess, center: [i32; 3], radius: i32, ) -> Vec<LightUpdate>
Clear all light in a cubic area and re-propagate from any emitters found.
Use when an opaque block is placed and you need to recalculate the area rather than tracing individual affected paths.